# ----------------------------- 以下是示例程序 -----------------------------
import suanpan
from suanpan.log import logger
from suanpan.simple_run import simple_run


def initialize(init_context):
    """初始化，组件启动时执行一次"""
    logger.info(f"initialize, {init_context}")


def run(context):
    """消息处理，每条消息都会执行"""
    message = context.args
    logger.info(f"message: {message}")
    logger.info('run ...')
    return f'Hello 算盘, {message.inputData1}!'


if __name__ == "__main__":
    simple_run()



import suanpan
from suanpan.app import app


@app.loadNodeArgs
def example(args):
    """
    获取输入端口数据方式:
        输入端口1： args.inputData1;
        输入端口2： args.inputData2...
        注：请在节点输入桩具体类型中配置数据类型，或自行转换
    发送至输出端口数据方式:
        单输出： return result
        多输出端口： {"out1": result1, "out2": result2...}
        发送某个端口：{"out2": result}
        注：请在节点输出桩具体类型中配置数据类型，否则下游节点可能会报错！
    获取参数列表参数值方式: args.param1, args.param2...args.param20
        注：默认载入的参数值为string, 如需转换请自行适配, 例如: int(args.param1)
    """
    # 在此处编辑用户自定义代码
    result = args.inputData1
    return f"Hello suanpan, I got in1: {result}"


if __name__ == "__main__":
    suanpan.run(app)
